==> eleventy-0.2.8.tgz: package/docs/coverage.md <==
# Code Coverage for Eleventy v0.2.8

| Filename                        | % Lines | % Statements | % Functions | % Branches |
| ------------------------------- | ------- | ------------ | ----------- | ---------- |
| `total`                         | 86.3%   | 86.3%        | 82.61%      | 80.26%     |
| `config.js`                     | 81.25%  | 81.25%       | 100%        | 83.33%     |
| `src/Config.js`                 | 100%    | 100%         | 100%        | 100%       |
| `src/Eleventy.js`               | 62.39%  | 62.39%       | 38.89%      | 45.45%     |
| `src/EleventyConfig.js`         | 90.91%  | 90.91%       | 84.62%      | 75%        |
| `src/EleventyError.js`          | 7.69%   | 7.69%        | 0%          | 0%         |
| `src/Template.js`               | 86.15%  | 86.15%       | 82.93%      | 77.03%     |
| `src/TemplateCollection.js`     | 92.31%  | 92.31%       | 100%        | 83.33%     |
| `src/TemplateConfig.js`         | 94.29%  | 94.29%       | 75%         | 91.67%     |
| `src/TemplateData.js`           | 98.57%  | 98.57%       | 100%        | 75%        |
| `src/TemplateGlob.js`           | 93.75%  | 93.75%       | 100%        | 87.5%      |
| `src/TemplateLayout.js`         | 97.44%  | 97.44%       | 100%        | 93.75%     |
| `src/TemplateMap.js`            | 96.97%  | 96.97%       | 100%        | 80%        |
| `src/TemplatePassthrough.js`    | 77.78%  | 77.78%       | 66.67%      | 100%       |
| `src/TemplatePath.js`           | 100%    | 100%         | 87.5%       | 100%       |
| `src/TemplatePermalink.js`      | 100%    | 100%         | 100%        | 100%       |
| `src/TemplateRender.js`         | 97.3%   | 97.3%        | 100%        | 85.71%     |
| `src/TemplateWriter.js`         | 72.03%  | 72.03%       | 60%         | 63.33%     |
| `src/Engines/Ejs.js`            | 100%    | 100%         | 100%        | 100%       |
| `src/Engines/Haml.js`           | 100%    | 100%         | 100%        | 100%       |
| `src/Engines/Handlebars.js`     | 100%    | 100%         | 100%        | 100%       |
| `src/Engines/Html.js`           | 100%    | 100%         | 100%        | 100%       |
| `src/Engines/JavaScript.js`     | 93.33%  | 93.33%       | 100%        | 100%       |
| `src/Engines/Liquid.js`         | 91.3%   | 91.3%        | 100%        | 50%        |
| `src/Engines/Markdown.js`       | 100%    | 100%         | 100%        | 100%       |
| `src/Engines/Mustache.js`       | 100%    | 100%         | 100%        | 100%       |
| `src/Engines/Nunjucks.js`       | 100%    | 100%         | 100%        | 100%       |
| `src/Engines/Pug.js`            | 100%    | 100%         | 100%        | 100%       |
| `src/Engines/TemplateEngine.js` | 96.77%  | 96.77%       | 88.89%      | 100%       |
| `src/Plugins/Pagination.js`     | 93.42%  | 93.42%       | 100%        | 87.5%      |
| `src/Util/Capitalize.js`        | 100%    | 100%         | 100%        | 100%       |
| `src/Util/Pluralize.js`         | 100%    | 100%         | 100%        | 100%       |
| `src/Util/Sortable.js`          | 86.67%  | 86.67%       | 76.19%      | 94.44%     |

==> eleventy-0.2.13.tgz: package/docs/coverage.md <==
# Code Coverage for Eleventy v0.2.11

| Filename                        | % Lines | % Statements | % Functions | % Branches |
| ------------------------------- | ------- | ------------ | ----------- | ---------- |
| `total`                         | 87.46%  | 87.46%       | 84.44%      | 81.79%     |
| `config.js`                     | 100%    | 100%         | 100%        | 100%       |
| `src/Config.js`                 | 100%    | 100%         | 100%        | 100%       |
| `src/Eleventy.js`               | 61.29%  | 61.29%       | 36.84%      | 38.46%     |
| `src/EleventyConfig.js`         | 90.91%  | 90.91%       | 84.62%      | 75%        |
| `src/EleventyError.js`          | 100%    | 100%         | 100%        | 100%       |
| `src/Template.js`               | 86.15%  | 86.15%       | 82.93%      | 77.03%     |
| `src/TemplateCollection.js`     | 92.31%  | 92.31%       | 100%        | 83.33%     |
| `src/TemplateConfig.js`         | 90.7%   | 90.7%        | 80%         | 92.86%     |
| `src/TemplateData.js`           | 98.57%  | 98.57%       | 100%        | 75%        |
| `src/TemplateGlob.js`           | 93.75%  | 93.75%       | 100%        | 87.5%      |
| `src/TemplateLayout.js`         | 97.44%  | 97.44%       | 100%        | 93.75%     |
| `src/TemplateMap.js`            | 96.97%  | 96.97%       | 100%        | 80%        |
| `src/TemplatePassthrough.js`    | 77.78%  | 77.78%       | 66.67%      | 100%       |
| `src/TemplatePath.js`           | 100%    | 100%         | 90%         | 100%       |
| `src/TemplatePermalink.js`      | 100%    | 100%         | 100%        | 100%       |
| `src/TemplateRender.js`         | 97.3%   | 97.3%        | 100%        | 85.71%     |
| `src/TemplateWriter.js`         | 72.03%  | 72.03%       | 60%         | 63.33%     |
| `src/Engines/Ejs.js`            | 100%    | 100%         | 100%        | 100%       |
| `src/Engines/Haml.js`           | 100%    | 100%         | 100%        | 100%       |
| `src/Engines/Handlebars.js`     | 100%    | 100%         | 100%        | 100%       |
| `src/Engines/Html.js`           | 100%    | 100%         | 100%        | 100%       |
| `src/Engines/JavaScript.js`     | 93.33%  | 93.33%       | 100%        | 100%       |
| `src/Engines/Liquid.js`         | 91.3%   | 91.3%        | 100%        | 50%        |
| `src/Engines/Markdown.js`       | 100%    | 100%         | 100%        | 100%       |
| `src/Engines/Mustache.js`       | 100%    | 100%         | 100%        | 100%       |
| `src/Engines/Nunjucks.js`       | 100%    | 100%         | 100%        | 100%       |
| `src/Engines/Pug.js`            | 100%    | 100%         | 100%        | 100%       |
| `src/Engines/TemplateEngine.js` | 96.77%  | 96.77%       | 88.89%      | 100%       |
| `src/Filters/Slug.js`           | 100%    | 100%         | 100%        | 100%       |
| `src/Filters/Url.js`            | 100%    | 100%         | 100%        | 100%       |
| `src/Plugins/Pagination.js`     | 93.42%  | 93.42%       | 100%        | 87.5%      |
| `src/Util/Capitalize.js`        | 100%    | 100%         | 100%        | 100%       |
| `src/Util/Pluralize.js`         | 100%    | 100%         | 100%        | 100%       |
| `src/Util/Sortable.js`          | 86.67%  | 86.67%       | 76.19%      | 94.44%     |
